pub type FieldBytesSize<C> = <C as Curve>::FieldBytesSize;Expand description
Size of serialized field elements of this elliptic curve.
main (development) branch of crypto-glue.pub type FieldBytesSize<C> = <C as Curve>::FieldBytesSize;Size of serialized field elements of this elliptic curve.